# MetaMask Institutional SDK (Beta)

🛑 The package `mmisdk` has been renamed `metamask-institutional.sdk`, and is no longer maintained under the name `mmisdk`.

✅ Use instead https://pypi.org/project/metamask-institutional.sdk.
